#
# spec file for package dotconf
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dotconf
Version:        1.3
Release:        16.9
Summary:        Configuration file parser library
License:        LGPL-2.1-or-later
Group:          Development/Languages/C and C++
URL:            https://github.com/williamh/dotconf/
Source:         https://github.com/williamh/dotconf/archive/v%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
dotconf is a configuration-file parser
library written in C. The configuration files created for dotconf look
similar to those used by the Apache web server. Even
container directives known from httpd.conf can be used in the
same manner as for Apache modules. It supports various types of
arguments, dynamically loadable modules that create their own
configuration options on-the-fly, a here-documents feature to pass
long ARG_STR data to programs, and on-the-fly inclusion of additional
config files.

%package -n libdotconf0
Summary:        Configuration file parser library
Group:          System/Languages
# Package was formerly libdotconf-1_0-0
Provides:       libdotconf-1_0-0 = %{version}
Obsoletes:      libdotconf-1_0-0 < %{version}

%description  -n libdotconf0
dotconf is a configuration-file parser
library written in C. The configuration files created for dotconf look
similar to those used by the Apache web server. Even
container directives known from httpd.conf can be used in the
same manner as for Apache modules. It supports various types of
arguments, dynamically loadable modules that create their own
configuration options on-the-fly, a here-documents feature to pass
long ARG_STR data to programs, and on-the-fly inclusion of additional
config files.

%package devel
Summary:        Configuration file parser library
Group:          Development/Languages/C and C++
Requires:       libdotconf0 = %{version}
# Package dotconf contained only documentation, which was moved here
Provides:       %{name} = %{version}-%{release}
Obsoletes:      %{name} < %{version}-%{release}

%description devel
dotconf is a configuration-file parser
library written in C. The configuration files created for dotconf look
similar to those used by the Apache web server. Even
container directives known from httpd.conf can be used in the
same manner as for Apache modules. It supports various types of
arguments, dynamically loadable modules that create their own
configuration options on-the-fly, a here-documents feature to pass
long ARG_STR data to programs, and on-the-fly inclusion of additional
config files.

%prep
%autosetup

%build
autoreconf -fiv
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
rm doc/Makefile*

%post -n libdotconf0 -p /sbin/ldconfig

%postun -n libdotconf0 -p /sbin/ldconfig

%files -n libdotconf0
%{_libdir}/libdotconf*.so.*

%files devel
%doc %{_datadir}/doc/dotconf/*
%dir %{_datadir}/doc/dotconf
%{_libdir}/libdotconf*.so
%{_libdir}/pkgconfig/dotconf.pc
%{_includedir}/dotconf.h

%changelog
* Wed Aug 11 2021 Jan Engelhardt <jengelh@inai.de>
- Drop --with-pic, as it has no effect with --disable-static.
- Trim filler wording from descriptions.
* Sun Oct 18 2015 mpluskal@suse.com
- Use url for source
- Move documentation to devel package
- Cleanup spec file with spec-cleaner
* Sun Feb  5 2012 jengelh@medozas.de
- Remove redundant tags/sections
- Remove dependencies on main package, which only has docs
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Wed Sep 21 2011 mgorse@suse.com
- Fix docs
- Fix package name to correspond with shared lib conventions, and obsolete
  old package
* Tue Sep 20 2011 mgorse@suse.com
- Remove files that are no longer installed
* Tue Sep 20 2011 mgorse@suse.com
- Switch URL to github.com/williamh and upgrade to v1.3 from there
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Sat Jun  6 2009 coolo@suse.de
- follow shared library policy
* Fri Mar 20 2009 crrodriguez@suse.de
- fix packaging of libraries
- remove static libraries except the ones only available in static form
* Mon May 12 2008 schwab@suse.de
- Use RPM_OPT_FLAGS.
- Remove junk.
* Sun Aug 12 2007 marco@suse.de
- moved some more files to devel package
- use bzip2 for source tarball
* Sat Jul 28 2007 ro@suse.de
- added defattr to devel package
* Fri Jul 27 2007 marco@suse.de
- initial version for opensuse (1.0.13)
  - James Cassidy sent in a little patch to add a 'pkg-config' file
  - Bastian Kleineidam sent in a patch for better support of 64bit architectures
  - Joost Remijn of eidetica.com sent in a patch fixing a nasty realloc()
    bug
  - Preston Smith fixed the compilation for systems where 'char' is
  handled as 'unsigned char' (like ARM)
    (for infos see http://www.arm.linux.org.uk/docs/faqs/signedchar.shtml)
  - Ross Alexander of NEC Europe sent in two patches to dotconf.m4, fixing
  version handling and prefix usage
  - a small fix for all RPM users out there. dotconf up to 1.0.9 did not put
    /usr/lib/libdotconf.so into the binary package
